/* Copyright 2021 Glorious, LLC <salman@pcgamingrace.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// RGB LED layout for GMMK 2 96%
// led number, function of the key
// Reference URLs:
//  https://gloriousforum.com/t/custom-qmk-for-gmmk-2-96-by-skitzo2000/12178
//  https://github.com/skitzo2000/GMMK2-96

//   0, Esc     1, F1     2, F2    3, F3     4, F4    5, F5     6, F6    7, F7     8, F8     9, F9     10, F10  11, F11     12, F12    13, Prnscr      14, Del     15, Ins     16, PgUp      17, PgDo

//  18, `      19, 1     20, 2    21, 3     22, 4    23, 5     24, 6    25, 7     26, 8     27, 9      28, 0    29, -       30, =      31, Bkspc       32, NmLk    33, /       34, *         35, -

//  36, Tab    37, Q     38, W    39, E     40, R    41, T     42, Y    43, U     44, I     45, O      46, P    47, [       48, ]      49, "\""        50, 7       51, 8       52, 9         53, +

//  54, CpsLk  55, A     56, S    57, D     58, F    59, G     60, H    61, J     62, K     63, L      64, ;    65, '       66, Enter                  67, 4       68, 5       69, 6

//  70, ShftL  71, Z     72, X    73, C     74, V    75, B     76, N    77, M     78, ,     79, .      80, /    81, ShftR              82, Up          83, 1       84, 2       85, 3         86, EntrR

//  87, CtlL   88, WinL   89, AltL                                90, Space              91, AltR  92, FN   93, CtrlR    94, Left      95, Down    96, Right       97, 0       98, Num .

//  Left side LEDs          //  Right side LEDs
//  101, LED 1              //  111, LED 11
//  102, LED 2              //  112, LED 12
//  103, LED 3              //  113, LED 13
//  104, LED 4              //  114, LED 14
//  105, LED 5              //  115, LED 15
//  106, LED 6              //  116, LED 16
//  107, LED 7              //  117, LED 17
//  108, LED 8              //  118, LED 18
//  109, LED 9              //  119, LED 19
//  110, LED 10             //  120, LED 20

#include QMK_KEYBOARD_H

// GMMK2 96 Default key group definitions
int FUNC_KEYS[] = {0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13,
                  18, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
                  36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
                  54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66,
                  70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
                  87, 88, 89, 90, 91, 92, 93
};
int NUM_KEYS[] = {32, 33, 34, 35, 50, 51, 52, 53, 67, 68, 69, 83, 84, 85, 86, 97, 98};

// Initialize the size of each key group
int SIZE_OF_FUNC_KEYS = sizeof(FUNC_KEYS)/sizeof(int);
int SIZE_OF_NUM_KEYS = sizeof(NUM_KEYS)/sizeof(int);

// Each layer gets a name for readability, which is then used in the keymap matrix below.
// The underscores don't mean anything - you can have a layer called STUFF or any other name.
#define _BL 0
#define _FL 1
#define _ML 2

const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
  /* Keymap _BL: Base Layer (Default Layer)
   */
[_BL] = LAYOUT(
  KC_ESC,            KC_F1,    KC_F2,    KC_F3,    KC_F4,    KC_F5,    KC_F6,    KC_F7,    KC_F8,    KC_F9,    KC_F10,   KC_F11,   KC_F12,   KC_PSCR,  KC_DEL,   KC_INS,   KC_PGUP,  KC_PGDN,
  KC_GRV,            KC_1,     KC_2,     KC_3,     KC_4,     KC_5,     KC_6,     KC_7,     KC_8,     KC_9,     KC_0,     KC_MINS,  KC_EQL,   KC_BSPC,  KC_NLCK,  KC_PSLS,  KC_PAST,  KC_PMNS,
  LT(_ML, KC_TAB),   KC_Q,     KC_W,     KC_E,     KC_R,     KC_T,     KC_Y,     KC_U,     KC_I,     KC_O,     KC_P,     KC_LBRC,  KC_RBRC,  KC_BSLS,  KC_P7,    KC_P8,    KC_P9,    KC_PPLS,
  LT(_FL, KC_CAPS),  KC_A,     KC_S,     KC_D,     KC_F,     KC_G,     KC_H,     KC_J,     KC_K,     KC_L,     KC_SCLN,  KC_QUOT,             KC_ENT,  KC_P4,    KC_P5,    KC_P6,
  KC_LSFT,           KC_Z,     KC_X,     KC_C,     KC_V,     KC_B,     KC_N,     KC_M,     KC_COMM,  KC_DOT,   KC_SLSH,  KC_RSFT,  KC_UP,    KC_P1,    KC_P2,    KC_P3,    KC_PENT,
  KC_LCTL,           KC_LGUI,  KC_LALT,                      KC_SPC,                                 KC_RALT,  MO(_FL),  KC_RCTL,  KC_LEFT,  KC_DOWN,  KC_RGHT,  KC_P0,    KC_PDOT),
  /* Keymap _FL: Function Layer
   */
[_FL] = LAYOUT(
    RESET,           KC_MYCM,  KC_WHOM,  KC_CALC,  KC_MSEL,  KC_MPRV,  KC_MRWD,  KC_MPLY,  KC_MSTP,  KC_MUTE,  KC_VOLU,  KC_VOLD,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,           RGB_HUI,  RGB_HUD,  RGB_SPD,  RGB_SPI,  _______,  RGB_TOG,  RGB_M_K,  RGB_M_X,  _______,  _______,  _______,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,         _______, LCA(KC_TAB), KC_BSPC,  _______,  _______,  _______,  KC_PGUP,  KC_HOME,  KC_END,   KC_BTN2,  _______,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,           _______,  _______,  KC_DEL,   _______,  _______,  KC_LEFT,  KC_DOWN,  KC_UP,    KC_RGHT,  _______,  _______,  _______,             _______,  _______,  _______,
  _______,           _______,  _______,  KC_CAPS,  _______,  _______,  KC_PGDN,  KC_APP,   _______,  _______,  _______,  _______,  RGB_VAI,   _______,  _______,  _______,  _______,
	_______,           UC_M_WI,  _______,                      _______,                                _______,  _______,  _______, RGB_RMOD,   RGB_VAD,  RGB_MOD,  _______,  _______),

  /* Keymap _ML: Mouse Layer
   */
[_ML] = LAYOUT(
  _______,           _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,           _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,           _______,  _______,  _______,  _______,  _______,  _______,  KC_BTN1,  _______,  KC_BTN2,  _______,  _______,  _______,   _______,  _______,  _______,  _______,  _______,
  _______,           _______,  _______,  _______,  _______,  _______,  KC_MS_L,  KC_MS_D,  KC_MS_U,  KC_MS_R,  _______,  _______,  _______,             _______,  _______,  _______,
  _______,           _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,  _______,   _______,  _______,  _______,  _______,
	_______,           _______,  _______,                      _______,                                _______,  _______,  _______,  _______,   _______,  _______,  _______,  _______)
};

void rgb_matrix_indicators_advanced_user(uint8_t led_min, uint8_t led_max) {
  if (IS_HOST_LED_ON(USB_LED_CAPS_LOCK)) {
    for(int i=0; i < SIZE_OF_FUNC_KEYS; i++) {
      RGB_MATRIX_INDICATOR_SET_COLOR(FUNC_KEYS[i], 255, 255, 255);
    }
  }
  else {
    for(int i=0; i < SIZE_OF_FUNC_KEYS; i++) {
      RGB_MATRIX_INDICATOR_SET_COLOR(FUNC_KEYS[i], 20, 20, 20);
    }
  }

  if (IS_HOST_LED_ON(USB_LED_NUM_LOCK)) {
    for(int i=0; i < SIZE_OF_NUM_KEYS; i++) {
      RGB_MATRIX_INDICATOR_SET_COLOR(NUM_KEYS[i], 255, 255, 255);
    }
  }
  else {
    for(int i=0; i < SIZE_OF_NUM_KEYS; i++) {
      RGB_MATRIX_INDICATOR_SET_COLOR(NUM_KEYS[i], 20, 20, 20);
    }
  }
}

void keyboard_post_init_user(void) {
  rgblight_enable_noeeprom();
  rgblight_set_speed(25);
}
